@@ -12,7 +12,7 @@ from langgraph_api.asyncio import ValueEvent, aclosing
 from langgraph_api.models.run import create_valid_run
 from langgraph_api.route import ApiRequest, ApiResponse, ApiRoute
 from langgraph_api.sse import EventSourceResponse
-from langgraph_api.utils import fetchone, validate_uuid
+from langgraph_api.utils import fetchone, get_pagination_headers, validate_uuid
 from langgraph_api.validation import (
     CronCreate,
     CronSearch,
@@ -116,7 +116,8 @@ async def stream_run(
             run["run_id"],
             thread_id=thread_id,
             cancel_on_disconnect=on_disconnect == "cancel",
-            stream_mode=await sub,
+            stream_channel=await sub,
+            stream_mode=payload.get("stream_mode", []),
             last_event_id=None,
         ),
         headers={
@@ -157,7 +158,8 @@ async def stream_run_stateless(
             thread_id=run["thread_id"],
             ignore_404=True,
             cancel_on_disconnect=on_disconnect == "cancel",
-            stream_mode=await sub,
+            stream_channel=await sub,
+            stream_mode=payload.get("stream_mode", []),
             last_event_id=None,
         ),
         headers={
@@ -200,13 +202,17 @@ async def wait_run(request: ApiRequest):
             Runs.Stream.join(
                 run["run_id"],
                 thread_id=run["thread_id"],
-                stream_mode=await sub,
+                stream_channel=await sub,
+                stream_mode=["updates", "values", "error"],
                 cancel_on_disconnect=on_disconnect == "cancel",
             )
         ) as stream:
             async for mode, chunk, _ in stream:
                 if mode == b"values":
                     vchunk = chunk
+                elif mode == b"updates" and b"__interrupt__" in chunk:
+                    # Include the interrupt message in the values
+                    vchunk = chunk
                 elif mode == b"error":
                     vchunk = orjson.dumps({"__error__": orjson.Fragment(chunk)})
         if vchunk is not None:
@@ -280,7 +286,8 @@ async def wait_run_stateless(request: ApiRequest):
             Runs.Stream.join(
                 run["run_id"],
                 thread_id=run["thread_id"],
-                stream_mode=await sub,
+                stream_channel=await sub,
+                stream_mode=["updates", "values", "error"],
                 ignore_404=True,
                 cancel_on_disconnect=on_disconnect == "cancel",
             )
@@ -288,6 +295,9 @@ async def wait_run_stateless(request: ApiRequest):
             async for mode, chunk, _ in stream:
                 if mode == b"values":
                     vchunk = chunk
+                elif mode == b"updates" and b"__interrupt__" in chunk:
+                    # Include the interrupt message in the values
+                    vchunk = chunk
                 elif mode == b"error":
                     vchunk = orjson.dumps({"__error__": orjson.Fragment(chunk)})
         if vchunk is not None:
@@ -396,7 +406,7 @@ async def join_run_stream(request: ApiRequest):
     cancel_on_disconnect = cancel_on_disconnect_str.lower() in {"true", "yes", "1"}
     validate_uuid(thread_id, "Invalid thread ID: must be a UUID")
     validate_uuid(run_id, "Invalid run ID: must be a UUID")
-    stream_mode = request.query_params.get("stream_mode") or None
+    stream_mode = request.query_params.get("stream_mode") or []
     last_event_id = request.headers.get("last-event-id") or None
     return EventSourceResponse(
         Runs.Stream.join(
@@ -452,8 +462,14 @@ async def cancel_runs(
                 status_code=422,
                 detail="Invalid status: must be 'pending', 'running', or 'all'",
             )
-        thread_id = None
+        if body.get("thread_id") or body.get("run_ids"):
+            raise HTTPException(
+                status_code=422,
+                detail="When providing a 'status', 'thread_id' and 'run_ids' must be omitted. "
+                "The 'status' parameter cancels all runs with the given status, regardless of thread or run ID.",
+            )
         run_ids = None
+        thread_id = None
     else:
         thread_id = body.get("thread_id")
         run_ids = body.get("run_ids")
@@ -552,20 +568,21 @@ async def search_crons(request: ApiRequest):
     if thread_id := payload.get("thread_id"):
         validate_uuid(thread_id, "Invalid thread ID: must be a UUID")
 
+    offset = int(payload.get("offset", 0))
     async with connect() as conn:
-        crons_iter, total = await Crons.search(
+        crons_iter, next_offset = await Crons.search(
             conn,
             assistant_id=assistant_id,
             thread_id=thread_id,
             limit=int(payload.get("limit", 10)),
-            offset=int(payload.get("offset", 0)),
+            offset=offset,
             sort_by=payload.get("sort_by"),
             sort_order=payload.get("sort_order"),
         )
-    return ApiResponse(
-        [cron async for cron in crons_iter],
-        headers={"X-Pagination-Total": str(total)},
+    crons, response_headers = await get_pagination_headers(
+        crons_iter, next_offset, offset
     )
+    return ApiResponse(crons, headers=response_headers)
 
 
 runs_routes = [
