@@ -3,6 +3,8 @@ from typing import Any
 from starlette.responses import Response, StreamingResponse
 from starlette.types import Send
 
+from langgraph_api.serde import Fragment
+
 """
 Patch Response.render and StreamingResponse.stream_response
 to recognize bytearrays and memoryviews as bytes-like objects.
@@ -28,6 +30,8 @@ async def StreamingResponse_stream_response(self, send: Send) -> None:
     async for chunk in self.body_iterator:
         if chunk is None:
             continue
+        if isinstance(chunk, Fragment):
+            chunk = chunk.buf
         if not isinstance(chunk, (bytes, bytearray, memoryview)):  # noqa: UP038
             chunk = chunk.encode(self.charset)
         await send({"type": "http.response.body", "body": chunk, "more_body": True})
