@@ -1,38 +1,49 @@
 # MONKEY PATCH: Patch Starlette to fix an error in the library
+# ruff: noqa: E402
 import langgraph_api.patch  # noqa: F401,I001
 import sys
+import os
 
 # WARNING: Keep the import above before other code runs as it
 # patches an error in the Starlette library.
 import logging
 import typing
 
+if not (
+    (disable_truststore := os.getenv("DISABLE_TRUSTSTORE"))
+    and disable_truststore.lower() == "true"
+):
+    import truststore  # noqa: F401
+
+    truststore.inject_into_ssl()  # noqa: F401
+
+from contextlib import asynccontextmanager
+
 import jsonschema_rs
 import structlog
-from contextlib import asynccontextmanager
 from langgraph.errors import EmptyInputError, InvalidUpdateError
+from langgraph_sdk.client import configure_loopback_transports
 from starlette.applications import Starlette
 from starlette.middleware import Middleware
 from starlette.middleware.cors import CORSMiddleware
-
-from langgraph_api.api.openapi import set_custom_spec
+from starlette.routing import Mount
 from starlette.types import Receive, Scope, Send
 
 import langgraph_api.config as config
-from langgraph_api.api import routes, meta_routes, user_router
-from starlette.routing import Mount
+from langgraph_api.api import meta_routes, routes, user_router
+from langgraph_api.api.openapi import set_custom_spec
 from langgraph_api.errors import (
     overloaded_error_handler,
     validation_error_handler,
     value_error_handler,
 )
-from langgraph_runtime.lifespan import lifespan
+from langgraph_api.js.base import is_js_path
 from langgraph_api.middleware.http_logger import AccessLoggerMiddleware
 from langgraph_api.middleware.private_network import PrivateNetworkMiddleware
+from langgraph_api.middleware.request_id import RequestIdMiddleware
 from langgraph_api.utils import SchemaGenerator
+from langgraph_runtime.lifespan import lifespan
 from langgraph_runtime.retry import OVERLOADED_EXCEPTIONS
-from langgraph_api.js.base import is_js_path
-from langgraph_sdk.client import configure_loopback_transports
 
 logging.captureWarnings(True)
 logger = structlog.stdlib.get_logger(__name__)
@@ -60,6 +71,7 @@ middleware.extend(
                 allow_credentials=True,
                 allow_methods=["*"],
                 allow_headers=["*"],
+                expose_headers=["x-pagination-total", "x-pagination-next"],
             )
             if config.CORS_CONFIG is None
             else Middleware(
@@ -68,6 +80,7 @@ middleware.extend(
             )
         ),
         Middleware(AccessLoggerMiddleware, logger=logger),
+        Middleware(RequestIdMiddleware, mount_prefix=config.MOUNT_PREFIX),
     ]
 )
 exception_handlers = {
@@ -184,7 +197,7 @@ if config.MOUNT_PREFIX:
                 # The SDK initialized with None is trying to connect via
                 # ASGITransport. Ensure that it has the correct subpath prefixes
                 # so the regular router can handle it.
-                scope["path"] = f'/noauth{prefix}{scope["path"]}'
+                scope["path"] = f"/noauth{prefix}{scope['path']}"
                 scope["raw_path"] = scope["path"].encode("utf-8")
 
             return await self.app(scope, receive, send)
