@@ -7,12 +7,12 @@ import langgraph.version
 import langsmith
 import structlog
 from langchain_core.messages import (
+    # TODO: Remove explicit dependency
     BaseMessage,
     BaseMessageChunk,
     convert_to_messages,
     message_chunk_to_message,
 )
-from langchain_core.runnables.config import run_in_executor
 from langgraph.errors import (
     EmptyChannelError,
     EmptyInputError,
@@ -24,14 +24,17 @@ from langsmith.utils import get_tracer_project
 from pydantic import ValidationError
 from pydantic.v1 import ValidationError as ValidationErrorLegacy
 
+from langgraph_api import __version__
 from langgraph_api import store as api_store
 from langgraph_api.asyncio import ValueEvent, wait_if_not_done
 from langgraph_api.command import map_cmd
+from langgraph_api.feature_flags import USE_RUNTIME_CONTEXT_API
 from langgraph_api.graph import get_graph
 from langgraph_api.js.base import BaseRemotePregel
 from langgraph_api.metadata import HOST, PLAN, USER_API_URL, incr_nodes
 from langgraph_api.schema import Run, StreamMode
 from langgraph_api.serde import json_dumpb
+from langgraph_api.utils.config import run_in_executor
 from langgraph_runtime.checkpoint import Checkpointer
 from langgraph_runtime.ops import Runs
 
@@ -93,6 +96,7 @@ async def astream_state(
     kwargs.pop("resumable", False)
     subgraphs = kwargs.get("subgraphs", False)
     temporary = kwargs.pop("temporary", False)
+    context = kwargs.pop("context", None)
     config = kwargs.pop("config")
     stack = AsyncExitStack()
     graph = await stack.enter_async_context(
@@ -114,10 +118,14 @@ async def astream_state(
     if "messages-tuple" in stream_modes_set and not isinstance(graph, BaseRemotePregel):
         stream_modes_set.remove("messages-tuple")
         stream_modes_set.add("messages")
+    if "updates" not in stream_modes_set:
+        stream_modes_set.add("updates")
+        only_interrupt_updates = True
     # attach attempt metadata
     config["metadata"]["run_attempt"] = attempt
     # attach langgraph metadata
     config["metadata"]["langgraph_version"] = langgraph.version.__version__
+    config["metadata"]["langgraph_api_version"] = __version__
     config["metadata"]["langgraph_plan"] = PLAN
     config["metadata"]["langgraph_host"] = HOST
     config["metadata"]["langgraph_api_url"] = USER_API_URL
@@ -221,7 +229,12 @@ async def astream_state(
                                 ),
                                 [message_chunk_to_message(messages[msg.id])],
                             )
-                    elif mode in stream_mode:
+                    elif mode in stream_mode or (
+                        mode == "updates"
+                        and isinstance(chunk, dict)
+                        and "__interrupt__" in chunk
+                        and only_interrupt_updates
+                    ):
                         if subgraphs and ns:
                             yield f"{mode}|{'|'.join(ns)}", chunk
                         else:
@@ -231,6 +244,8 @@ async def astream_state(
                     yield "events", event
     else:
         output_keys = kwargs.pop("output_keys", graph.output_channels)
+        if USE_RUNTIME_CONTEXT_API:
+            kwargs["context"] = context
         async with (
             stack,
             aclosing(
@@ -285,7 +300,12 @@ async def astream_state(
                             ),
                             [message_chunk_to_message(messages[msg.id])],
                         )
-                elif mode in stream_mode:
+                elif mode in stream_mode or (
+                    mode == "updates"
+                    and isinstance(chunk, dict)
+                    and "__interrupt__" in chunk
+                    and only_interrupt_updates
+                ):
                     if subgraphs and ns:
                         yield f"{mode}|{'|'.join(ns)}", chunk
                     else:
@@ -318,7 +338,6 @@ async def consume(stream: AnyStream, run_id: str, resumable: bool = False) -> No
                     resumable=resumable,
                 )
         except Exception as e:
-            g = e
             if isinstance(e, ExceptionGroup):
                 e = e.exceptions[0]
             await Runs.Stream.publish(
@@ -327,7 +346,7 @@ async def consume(stream: AnyStream, run_id: str, resumable: bool = False) -> No
                 await run_in_executor(None, json_dumpb, e),
                 resumable=resumable,
             )
-            raise e from g
+            raise e
 
 
 def get_feedback_urls(run_id: str, feedback_keys: list[str]) -> dict[str, str]:
